@@ -35,6 +35,7 @@
 #include "gtkmarshalers.h"
 #include "gtkbox.h"
 #include "gtkboxprivate.h"
+#include "gtkcontainerprivate.h"
 #include "gtkmain.h"
 #include "gtkintl.h"
 #include "gtkbindings.h"
@@ -302,6 +303,8 @@ apply_use_header_bar (GtkDialog *dialog)
           gtk_widget_show (box);
           gtk_widget_set_size_request (box, -1, 16);
           label = gtk_label_new ("");
+          gtk_widget_set_margin_top (label, 6);
+          gtk_widget_set_margin_bottom (label, 6);
           gtk_style_context_add_class (gtk_widget_get_style_context (label), "title");
           gtk_box_set_center_widget (GTK_BOX (box), label);
           g_signal_connect_object (dialog, "notify::title", G_CALLBACK (update_title), label, 0);
@@ -564,6 +567,15 @@ gtk_dialog_class_init (GtkDialogClass *class)
 		  _gtk_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
 
+  /**
+   * GtkDialog:content-area-border:
+   *
+   * The default border width used around the
+   * content area of the dialog, as returned by
+   * gtk_dialog_get_content_area(), unless gtk_container_set_border_width()
+   * was called on that widget directly.
+   *
+   */
   gtk_widget_class_install_style_property (widget_class,
 					   g_param_spec_int ("content-area-border",
                                                              P_("Content area border"),
@@ -654,9 +666,11 @@ update_spacings (GtkDialog *dialog)
                         "button-spacing", &button_spacing,
                         "action-area-border", &action_area_border,
                         NULL);
-  
-  gtk_container_set_border_width (GTK_CONTAINER (priv->vbox),
-                                  content_area_border);
+
+  if (!_gtk_container_get_border_width_set (GTK_CONTAINER (priv->vbox)))
+    gtk_container_set_border_width (GTK_CONTAINER (priv->vbox),
+                                    content_area_border);
+
   if (!_gtk_box_get_spacing_set (GTK_BOX (priv->vbox)))
     {
       gtk_box_set_spacing (GTK_BOX (priv->vbox), content_area_spacing);
@@ -665,8 +679,10 @@ update_spacings (GtkDialog *dialog)
 
   gtk_box_set_spacing (GTK_BOX (priv->action_area),
                        button_spacing);
-  gtk_container_set_border_width (GTK_CONTAINER (priv->action_area),
-                                  action_area_border);
+
+  if (!_gtk_container_get_border_width_set (GTK_CONTAINER (priv->action_area)))
+    gtk_container_set_border_width (GTK_CONTAINER (priv->action_area),
+                                    action_area_border);
 }
 
 static void
