@@ -148,11 +148,6 @@ GtkTextDirection gtk_get_locale_direction (void);
 GDK_AVAILABLE_IN_ALL
 gboolean       gtk_events_pending       (void);
 
-#ifndef GTK_DISABLE_DEPRECATED
-void     gtk_exit                 (gint    error_code);
-gchar *        gtk_set_locale           (void);
-#endif /* GTK_DISABLE_DEPRECATED */
-
 GDK_AVAILABLE_IN_ALL
 void       gtk_main_do_event       (GdkEvent           *event);
 GDK_AVAILABLE_IN_ALL
