@@ -135,7 +135,7 @@ enum
 {
   PROP_0,
   PROP_POPUP,
-  PROP_MODEL,
+  PROP_MENU_MODEL,
   PROP_ALIGN_WIDGET,
   PROP_DIRECTION,
   PROP_USE_POPOVER,
@@ -159,7 +159,7 @@ gtk_menu_button_set_property (GObject      *object,
       case PROP_POPUP:
         gtk_menu_button_set_popup (self, g_value_get_object (value));
         break;
-      case PROP_MODEL:
+      case PROP_MENU_MODEL:
         gtk_menu_button_set_menu_model (self, g_value_get_object (value));
         break;
       case PROP_ALIGN_WIDGET:
@@ -192,7 +192,7 @@ gtk_menu_button_get_property (GObject    *object,
       case PROP_POPUP:
         g_value_set_object (value, priv->menu);
         break;
-      case PROP_MODEL:
+      case PROP_MENU_MODEL:
         g_value_set_object (value, priv->model);
         break;
       case PROP_ALIGN_WIDGET:
@@ -519,7 +519,7 @@ gtk_menu_button_class_init (GtkMenuButtonClass *klass)
    * Since: 3.6
    */
   g_object_class_install_property (gobject_class,
-                                   PROP_MODEL,
+                                   PROP_MENU_MODEL,
                                    g_param_spec_object ("menu-model",
                                                         P_("Menu model"),
                                                         P_("The model from which the popup is made."),
@@ -708,6 +708,8 @@ _gtk_menu_button_set_popup_with_func (GtkMenuButton                 *menu_button
       gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (menu_button)), "menu-button");
     }
 
+  gtk_widget_set_sensitive (GTK_WIDGET (menu_button), priv->menu != NULL);
+
   g_object_notify (G_OBJECT (menu_button), "popup");
   g_object_notify (G_OBJECT (menu_button), "menu-model");
 }
@@ -732,6 +734,8 @@ gtk_menu_button_set_popup (GtkMenuButton *menu_button,
   g_return_if_fail (GTK_IS_MENU_BUTTON (menu_button));
   g_return_if_fail (GTK_IS_MENU (menu) || menu == NULL);
 
+  g_object_freeze_notify (G_OBJECT (menu_button));
+
   g_clear_object (&priv->model);
 
   _gtk_menu_button_set_popup_with_func (menu_button, menu, NULL, NULL);
@@ -741,6 +745,8 @@ gtk_menu_button_set_popup (GtkMenuButton *menu_button,
 
   gtk_widget_set_sensitive (GTK_WIDGET (menu_button),
                             priv->menu != NULL || priv->popover != NULL);
+
+  g_object_thaw_notify (G_OBJECT (menu_button));
 }
 
 /**
@@ -792,30 +798,39 @@ gtk_menu_button_set_menu_model (GtkMenuButton *menu_button,
 
   priv = menu_button->priv;
 
-  g_clear_object (&priv->model);
-  gtk_menu_button_set_popup (menu_button, NULL);
-  gtk_menu_button_set_popover (menu_button, NULL);
+  g_object_freeze_notify (G_OBJECT (menu_button));
 
-  if (menu_model == NULL)
-    return;
+  if (menu_model)
+    g_object_ref (menu_model);
 
-  priv->model = g_object_ref (menu_model);
-
-  if (priv->use_popover)
+  if (menu_model)
     {
-      GtkWidget *popover;
+      if (priv->use_popover)
+        {
+          GtkWidget *popover;
 
-      popover = gtk_popover_new_from_model (GTK_WIDGET (menu_button), menu_model);
-      gtk_menu_button_set_popover (menu_button, popover);
+          popover = gtk_popover_new_from_model (GTK_WIDGET (menu_button), menu_model);
+          gtk_menu_button_set_popover (menu_button, popover);
+        }
+      else
+        {
+          GtkWidget *menu;
+
+          menu = gtk_menu_new_from_model (menu_model);
+          gtk_widget_show_all (menu);
+          gtk_menu_button_set_popup (menu_button, menu);
+        }
     }
   else
     {
-      GtkWidget *menu;
-
-      menu = gtk_menu_new_from_model (menu_model);
-      gtk_widget_show_all (menu);
-      gtk_menu_button_set_popup (menu_button, menu);
+      gtk_menu_button_set_popup (menu_button, NULL);
+      gtk_menu_button_set_popover (menu_button, NULL);
     }
+
+  priv->model = menu_model;
+  g_object_notify (G_OBJECT (menu_button), "menu-model");
+
+  g_object_thaw_notify (G_OBJECT (menu_button));
 }
 
 /**
@@ -1045,7 +1060,14 @@ gtk_menu_button_set_use_popover (GtkMenuButton *menu_button,
 
   priv->use_popover = use_popover;
 
+  g_object_freeze_notify (G_OBJECT (menu_button));
+
+  if (priv->model)
+    gtk_menu_button_set_menu_model (menu_button, priv->model);
+
   g_object_notify (G_OBJECT (menu_button), "use-popover");
+
+  g_object_thaw_notify (G_OBJECT (menu_button));
 }
 
 /**
@@ -1055,7 +1077,7 @@ gtk_menu_button_set_use_popover (GtkMenuButton *menu_button,
  * Returns whether a #GtkPopover or a #GtkMenu will be constructed
  * from the menu model.
  *
- * Return value: %TRUE if using a #GtkPopover
+ * Returns: %TRUE if using a #GtkPopover
  *
  * Since: 3.12
  */
@@ -1087,6 +1109,8 @@ gtk_menu_button_set_popover (GtkMenuButton *menu_button,
   g_return_if_fail (GTK_IS_MENU_BUTTON (menu_button));
   g_return_if_fail (GTK_IS_POPOVER (popover) || popover == NULL);
 
+  g_object_freeze_notify (G_OBJECT (menu_button));
+
   g_clear_object (&priv->model);
 
   if (priv->popover)
@@ -1115,6 +1139,10 @@ gtk_menu_button_set_popover (GtkMenuButton *menu_button,
 
   gtk_widget_set_sensitive (GTK_WIDGET (menu_button),
                             priv->menu != NULL || priv->popover != NULL);
+
+  g_object_notify (G_OBJECT (menu_button), "popover");
+  g_object_notify (G_OBJECT (menu_button), "menu-model");
+  g_object_freeze_notify (G_OBJECT (menu_button));
 }
 
 /**
