@@ -32,11 +32,9 @@
  * from a provided #GtkStyleContext; see
  * gtk_numerable_icon_set_style_context().
  *
- * <example>
- * <title>Typical numerable icons</title>
- * <inlinegraphic fileref="numerableicon.png" format="PNG"/>
- * <inlinegraphic fileref="numerableicon2.png" format="PNG"/>
- * </example>
+ * Typical numerable icons:
+ * ![](numerableicon.png)
+ * ![](numerableicon2.png)
  */
 #include <config.h>
 
@@ -93,7 +91,7 @@ enum {
 
 static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
-G_DEFINE_TYPE (GtkNumerableIcon, gtk_numerable_icon, G_TYPE_EMBLEMED_ICON);
+G_DEFINE_TYPE_WITH_PRIVATE (GtkNumerableIcon, gtk_numerable_icon, G_TYPE_EMBLEMED_ICON)
 
 static gint
 get_surface_size (cairo_surface_t *surface)
@@ -196,7 +194,6 @@ draw_from_gicon (GtkNumerableIcon *self)
   GtkIconInfo *info;
   GdkPixbuf *pixbuf;
   cairo_surface_t *surface;
-  cairo_t *cr;
 
   if (self->priv->style != NULL)
     {
@@ -215,21 +212,12 @@ draw_from_gicon (GtkNumerableIcon *self)
     return NULL;
 
   pixbuf = gtk_icon_info_load_icon (info, NULL);
-  gtk_icon_info_free (info);
+  g_object_unref (info);
 
   if (pixbuf == NULL)
     return NULL;
 
-  surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
-                                        gdk_pixbuf_get_width (pixbuf),
-                                        gdk_pixbuf_get_height (pixbuf));
-
-  cr = cairo_create (surface);
-
-  gdk_cairo_set_source_pixbuf (cr, pixbuf, 0, 0);
-  cairo_paint (cr);
-
-  cairo_destroy (cr);
+  surface = gdk_cairo_surface_create_from_pixbuf (pixbuf, 1, NULL);
   g_object_unref (pixbuf);
 
   return surface;
@@ -646,8 +634,6 @@ gtk_numerable_icon_class_init (GtkNumerableIconClass *klass)
   oclass->dispose = gtk_numerable_icon_dispose;
   oclass->finalize = gtk_numerable_icon_finalize;
 
-  g_type_class_add_private (klass, sizeof (GtkNumerableIconPrivate));
-
   properties[PROP_COUNT] =
     g_param_spec_int ("count",
                       P_("Icon's count"),
@@ -692,9 +678,7 @@ gtk_numerable_icon_init (GtkNumerableIcon *self)
   GdkRGBA bg;
   GdkRGBA fg;
 
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-                                            GTK_TYPE_NUMERABLE_ICON,
-                                            GtkNumerableIconPrivate);
+  self->priv = gtk_numerable_icon_get_instance_private (self);
 
   gdk_rgba_parse (&bg, DEFAULT_BACKGROUND);
   gdk_rgba_parse (&fg, DEFAULT_FOREGROUND);
@@ -828,7 +812,7 @@ gtk_numerable_icon_set_count (GtkNumerableIcon *self,
  * @self: a #GtkNumerableIcon
  *
  * Returns the #GtkStyleContext used by the icon for theming,
- * or %NULL if there's none.
+ * or %NULL if there’s none.
  *
  * Returns: (transfer none): a #GtkStyleContext, or %NULL.
  *     This object is internal to GTK+ and should not be unreffed.
@@ -919,7 +903,7 @@ gtk_numerable_icon_set_background_gicon (GtkNumerableIcon *self,
  * @self: a #GtkNumerableIcon
  *
  * Returns the #GIcon that was set as the base background image, or
- * %NULL if there's none. The caller of this function does not own
+ * %NULL if there’s none. The caller of this function does not own
  * a reference to the returned #GIcon.
  *
  * Returns: (transfer none): a #GIcon, or %NULL
@@ -989,7 +973,7 @@ gtk_numerable_icon_set_background_icon_name (GtkNumerableIcon *self,
  * @self: a #GtkNumerableIcon
  *
  * Returns the icon name used as the base background image,
- * or %NULL if there's none.
+ * or %NULL if there’s none.
  *
  * Returns: an icon name, or %NULL
  *
